<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific apmt_locationuage governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English apmt_locationuage pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Calendar',
'LBL_MODULE_TITLE'=>'Calendar: Home',
'LBL_MODULE_APPOINTMENT'=>'Calendar: Appointment',
'LBL_MODULE_APPOINTMENT_DETAIL'=>'Calendar: Appointment Detail',
'LBL_SAVE'=>'Save',
'LBL_RESET'=>'Cancel',
'LBL_LIST_USER_NAME'=>'User Name',
'LBL_LIST_NAME'=>'Name',
'LBL_CALENDAR_SHARED'=>'Calendar currently shared with',
'LBL_CALENDAR_SHARING'=>'Share calendar with',
'LBL_SHARING_OPTION'=>'Can see my calendar?',
'LBL_LIST_TOOLS'=>'Tools',
'LBL_SETTINGS'=>'Settings',
'LBL_CALSETTINGS'=>'Calendar Settings',
'LBL_USE24'=>'Use 24 hours format',
'LBL_CALSTART'=>'Start my calendar time at',
'LBL_TIMESETTINGS'=>'Time Settings',
'LBL_HOLDFOLLOWUP'=>'Hold followup on',
'LBL_CALL' => 'Call',
'LBL_MEET' => 'Meeting',
'LBL_APPNT' => 'Appointment',
'LBL_NEW_APPNT' => 'New Appointment',
'LBL_NEW_APPNT_INFO' => 'Create a new appointment',
'LBL_VIEW_DAY_APPNT_INFO' => 'View appointment(s) for this day',
'LBL_CHANGE_APPNT' => 'see or change this appointment (%s - %s)',

'LBL_DAY' => 'Day',
'LBL_DAY_BUTTON_KEY' => 'D',
'LBL_DAY_BUTTON_TITLE' => 'Day [Alt+D]',
'LBL_DAY1' => 'Monday',
'LBL_DAY2' => 'Tuesday',
'LBL_DAY3' => 'Wednesday',
'LBL_DAY4' => 'Thursday',
'LBL_DAY5' => 'Friday',
'LBL_DAY6' => 'Saturday',
'LBL_DAY0' => 'Sunday',

'LBL_SM_MON' => 'Mon',
'LBL_SM_TUE' => 'Tue',
'LBL_SM_WED' => 'Wed',
'LBL_SM_THU' => 'Thu',
'LBL_SM_FRI' => 'Fri',
'LBL_SM_SAT' => 'Sat',
'LBL_SM_SUN' => 'Sun',

'LBL_DATE_TITLE' => 'Day %d, %A',

'LBL_WEEK' => 'Week',
'LBL_WEEK_BUTTON_KEY' => 'W',
'LBL_WEEK_BUTTON_TITLE' => 'Week [Alt+W]',
'LBL_WEEKS' => 'Weeks',
'LBL_NEXT_WEEK' => 'next week',
'LBL_LAST_WEEK' => 'last week',
'LBL_4WEEKS_BACK' => '4 weeks back',
'LBL_4WEEKS_PLUS' => '4 weeks plus',
'LBL_RELOAD' => 'Reload',


'LBL_APPCREATED_BY' => 'Created by',
'LBL_AT_DATE_TIME' => 'at',

'LBL_MON' => 'Month',
'LBL_MON_BUTTON_KEY' => 'M',
'LBL_MON_BUTTON_TITLE' => 'Month [Alt+M]',
'LBL_PREV_MON' => 'Previous Month',
'LBL_NEXT_MON' => 'Next Month',

'LBL_YEAR_BUTTON_KEY'=>'Y',
'LBL_PREV_YEAR'=>'Previous Year',
'LBL_NEXT_YEAR' => 'Next Year',

'LBL_APP_LOCATION' => 'Location',
'LBL_APP_IGNORE_TIME' => 'ignore above times',
'LBL_SUBJECT'=>'Subject:',
'LBL_APP_DESCRIPTION' => 'Description',
'LBL_CONTACT'=>'Contact:',
'LBL_CONTACT_LIST'=>'Contact List:',

'LBL_APP_IGNORE_TIME2' => '(i.e. the appointment takes place<br />at no particular time on these day(s) )',

'LBL_APP_ERR001' =>'Invalid Date in field %s!',
'LBL_APP_ERR002' =>'start after end !',
'LBL_APP_ERR003' =>'Missing Contact !',
'LBL_APP_ERR004' =>'Missing Subject !',
'ERR_DELETE_RECORD'=>"A record number must be specified to delete the appointment.",
'DELETE_CONFIRMATION'=>"Are you sure you want to delete this appointment?",

'AppLoc'=> Array('0' => 'Office'
			, '1' => 'Out'
			, '2' => 'Vacation'
			, '3' => 'sick'
			, '4' => 'Postponed'
			, '5' => 'Option'
			, '6' => 'Private'),

'cal_month_long'=>array(
"",
"January",
"February",
"March",
"April",
"May",
"June",
"July",
"August",
"September",
"October",
"November",
"December",
),

'cal_weekdays_short'=>array(
"Sun",
"Mon",
"Tue",
"Wed",
"Thu",
"Fri",
"Sat",
),
'cal_weekdays_long'=>array(
"Sunday",
"Monday",
"Tuesday",
"Wednesday",
"Thursday",
"Friday",
"Saturday",
),
'cal_month_short'=>array(
"",
"Jan",
"Feb",
"Mar",
"Apr",
"May",
"Jun",
"Jul",
"Aug",
"Sep",
"Oct",
"Nov",
"Dec",
),

'LBL_TIME'=>'Time',
'LBL_START_TIME' => 'Start Time',
'LBL_END_TIME' => 'End Time',
'LBL_START_DATE'=>'Start Date',
'LBL_TIME_START'=>'Time Start',
'LBL_DUE_DATE'=>'Due Date',
'LBL_START_DATE_TIME'=>'Start Date & Time',
'LBL_END_DATE_TIME'=>'End Date & Time',
'LBL_TODO'=>'To Do',
'LBL_TODOS'=>'To Dos',
'LBL_EVENTS'=>'Events',
'LBL_TOTALEVENTS'=>'My Total Events :',
'LBL_TOTALTODOS'=>'My Total To Dos :',
'LBL_VIEW'=>'View',
'LBL_LISTVIEW'=>'List View',
'LBL_HRVIEW'=>'Hour View',
'LBL_WEEKVIEW'=>'Weekly Calendar View',
'LBL_MONTHVIEW'=>'Monthly Calendar View',
'LBL_YEARVIEW'=>'Yearly Calendar View',
'LBL_STATUS'=>'Status',
'LBL_ACTION'=>'Actions',
'LBL_ADD'=>'Add',
'LBL_OPENCAL'=>'Open Calendar',


'LBL_ADD_EVENT'=>'Add Event',
'LBL_ADDCALL'=>'Call',
'LBL_ADDMEETING'=>'Meeting',
'LBL_ADDTODO'=>'To Do',
'LBL_BEFOREEVENT'=>'before the event starts',
'LBL_BEFORETASK'=>'before the task starts',
'LBL_EVENTDETAILS'=>'Event Details',
'LBL_CURSTATUS'=>'Current Status',
'LBL_ASSINGEDTO'=>'Assigned To',
'LBL_RELATEDTO'=>'Related To',
'LBL_PENDING'=>'Pending',
'LBL_PUBLIC'=>'Mark Public',
'LBL_MORE'=>'More',
'LBL_EDIT'=>'Edit',
'LBL_EVERYDAY'=>'Every Day',
'LBL_EVERYWEEK'=>'Every Week',
'LBL_EVERYMON'=>'Every Month',
'LBL_WEEKS'=>'Week(s)',
'LBL_MONTHS'=>'Month(s)',
'LBL_YEAR'=>'Year',
'LBL_NONE_SCHEDULED'=>'None Scheduled',

'LBL_INVITE_INST1'=>'To invite, select the users from the "Available Users" list and click the "Add" button.',
'LBL_INVITE_SHARE'=>'To share, select the users from the "Available Users" list and click the "Add" button.',
'LBL_INVITE_INST2'=>'To remove, select the users from the "Selected Users" list and the click "Remove" button.',
'LBL_SELUSR_INFO'=>' Selected users will receive an email about the Event.',
'LBL_CALSHAREMESSAGE'=>'Share my calendar with the following selected users',
'LBL_CALSHARE'=>'Calendar Sharing',
'LBL_SEL_USERS'=>'Selected Users',
'LBL_AVL_USERS'=>'Available Users',
'LBL_ADD_BUTTON'=>'Add',
'LBL_USERS'=>'Users',
'LBL_RMV_BUTTON'=>'Remove',
'LBL_SDRMD'=>'Send Reminder to',
'LBL_ENABLE_REPEAT'=>'Enable Repeat',
'LBL_REPEAT_ONCE'=>'Repeat once in every',
'LBL_ADD_TODO'=>'Create To Do',
'LBL_TODONAME'=>'To Do',
'LBL_TODODATETIME'=>'Time & Date',





//DON'T CONVERT THESE THEY ARE MAPPINGS - STARTS
'db_last_name' => 'LBL_LIST_LAST_NAME',
'db_first_name' => 'LBL_LIST_FIRST_NAME',
'db_title' => 'LBL_LIST_TITLE',
'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
'db_email2' => 'LBL_LIST_EMAIL_ADDRESS',
//DON'T CONVERT THESE THEY ARE MAPPINGS -ENDS
'LBL_COMPLETED'=>'Mark Completed',
'LBL_DEFERRED'=>'Mark Deferred',
'LBL_HELD'=>'Mark Held',
'LBL_NOTHELD'=>'Mark Not Held',
'LBL_POSTPONE'=>'Postpone',
'LBL_CHANGEOWNER'=>'Change Owner',
'LBL_DEL'=>'Delete',

//Added for actvity merge with calendar
'LBL_SEARCH_FORM_TITLE'=>'Activity Search',
'LBL_LIST_FORM_TITLE'=>'Activity List',
'LBL_NEW_FORM_TITLE'=>'New Activity',
'LBL_TASK_INFORMATION'=>'Task Information',
'LBL_EVENT_INFORMATION'=>'Event Information',
'LBL_CALENDAR_INFORMATION'=>'Calendar Information',

'LBL_NAME'=>'Subject:',
'LBL_ACTIVITY_NOTIFICATION'=>'This is a notification that an activity is assigned to you that has been',
'LBL_ACTIVITY_INVITATION'=>'You have been invited for an activity that has been ',
'LBL_DETAILS_STRING'=>'The details are',
'LBL_REGARDS_STRING'=>'Thanks & Regards',
'LBL_CONTACT_NAME'=>'Contact Name',
'LBL_OPEN_ACTIVITIES'=>'Open Activities',
'LBL_ACTIVITY'=>'Activity:',
'LBL_HISTORY'=>'History',
'LBL_UPCOMING'=>"My Upcoming and Pending Activities",
'LBL_TODAY'=>'through ',

'LBL_NEW_TASK_BUTTON_TITLE'=>'New Task [Alt+N]',
'LBL_NEW_TASK_BUTTON_KEY'=>'N',
'LBL_NEW_TASK_BUTTON_LABEL'=>'New Task',
'LBL_SCHEDULE_MEETING_BUTTON_TITLE'=>'Schedule Meeting [Alt+M]',
'LBL_SCHEDULE_MEETING_BUTTON_KEY'=>'M',
'LBL_SCHEDULE_MEETING_BUTTON_LABEL'=>'Schedule Meeting',
'LBL_SCHEDULE_CALL_BUTTON_TITLE'=>'Schedule Call [Alt+C]',
'LBL_SCHEDULE_CALL_BUTTON_KEY'=>'C',
'LBL_SCHEDULE_CALL_BUTTON_LABEL'=>'Schedule Call',
'LBL_NEW_NOTE_BUTTON_TITLE'=>'New Document [Alt+T]',
'LBL_NEW_ATTACH_BUTTON_TITLE'=>'Attach File [Alt+F]',
'LBL_NEW_NOTE_BUTTON_KEY'=>'T',
'LBL_NEW_ATTACH_BUTTON_KEY'=>'F',
'LBL_NEW_NOTE_BUTTON_LABEL'=>'New Document',
'LBL_NEW_ATTACH_BUTTON_LABEL'=>'Attach File',
'LBL_TRACK_EMAIL_BUTTON_TITLE'=>'Track Email [Alt+K]',
'LBL_TRACK_EMAIL_BUTTON_KEY'=>'K',
'LBL_TRACK_EMAIL_BUTTON_LABEL'=>'Track Email',

'LBL_LIST_CLOSE'=>'Close',
'LBL_LIST_STATUS'=>'Status',
'LBL_LIST_CONTACT'=>'Contact',
//Added for 4.2 release for Account column support as shown by Fredy
'LBL_LIST_ACCOUNT'=>'Account',
'LBL_LIST_RELATED_TO'=>'Related to',
'LBL_LIST_DUE_DATE'=>'Due Date',
'LBL_LIST_DATE'=>'Date',
'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_LAST_MODIFIED'=>'Last Modified',
'LBL_LIST_RECURRING_TYPE'=>'Recurring Type',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the vtiger_account.",
'NTC_NONE_SCHEDULED'=>'None scheduled.',

// Added vtiger_fields for Attachments in Activities/SubPanelView.php
'LBL_ATTACHMENTS'=>'Attachments',
'LBL_NEW_ATTACHMENT'=>'New Attachment',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_CALL'=>'Call',
'LBL_MEETING'=>'Meeting',
'LBL_TASK'=>'Task',

//Added for 4GA Release
'Subject'=>'Subject',
'Assigned To'=>'Assigned To',
'Start Date & Time'=>'Start Date & Time',
'Time Start'=>'Time Start',
'Due Date'=>'Due Date',
'Related To'=>'Related to',
'Contact Name'=>'Contact Name',
'Status'=>'Status',
'Priority'=>'Priority',
'Visibility'=>'Visibility',
'Send Notification'=>'Send Notification',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Activity Type'=>'Activity Type',
'Description'=>'Description',
'Duration'=>'Duration',
'Duration Minutes'=>'Duration Minutes',
'Location'=>'Location',
'No Time'=>'No Time',
//Added for Send Reminder 4.2 release
'Send Reminder'=>'Send Reminder',
'LBL_YES'=>'Yes',
'LBL_NO'=>'No',
'LBL_DAYS'=>'day(s)',
'LBL_MINUTES'=>'minutes',
'LBL_HOURS'=>'hours',
'LBL_BEFORE_EVENT'=>'before event',
//Added for CustomView 4.2 Release
'Close'=>'Close',
'Start Date'=>'Start Date',
'Type'=>'Type',
'End Date'=>'End Date',
'Recurrence'=> 'Recurring Events',
'Recurring Type'=> 'Recurring Type',
//Activities - Notification Error
'LBL_NOTIFICATION_ERROR'=>'Mail Error : Please check your outgoing mail server configuration in Settings->Outgoing Mail Server Configuration OR MailId for the present user is not Configured',
// Mike Crowe Mod --------------------------------------------------------added for generic search
'LBL_GENERAL_INFORMATION'=>'General Information',

'LBL_EVENTTYPE'=>'Event Type',
'LBL_EVENTNAME'=>'Event Name',
'LBL_EVENTSTAT'=>'Event starts at',
'LBL_EVENTEDAT'=>'Event ends on',
'LBL_INVITE'=>'Invite',
'LBL_REPEAT'=>'Repeat',
'LBL_REMINDER'=>'Reminder',
'LBL_SENDREMINDER'=>'Send Reminder',
'LBL_NOTIFICATION'=>'Notification',
'LBL_SENDNOTIFICATION'=>'Send Notification',
'LBL_RMD_ON'=>'Remind on',
'LBL_REPEATEVENT'=>'Repeat once in every',
'LBL_TIMEDATE'=>'Time & Date',
'LBL_HR'=>'Hr',
'LBL_MIN'=>'min',
'LBL_EVENT'=>'Event',
'Daily'=>'Day(s)',
'Weekly'=>'Week(s)',
'Monthly'=>'Month(s)',
'Yearly'=>'Year',
'createdtime'=>'Created Time',
'modifiedtime'=>'Modified Time',
'first'=>'First',
'last'=>'Last',
'High'=>'High',
'Medium'=>'Medium',
'Low'=>'Low',
'LBL_SELECT'=>'Select',
'LBL_ALL_EVENTS_TODOS'=>'All Events & Todos',
'First'=>'First', 
'Last'=>'Last', 
'on'=>'on', 
'day of the month'=>'day of the month',
'Private'=>'Private',
'Public'=>'Public',

//Added for existing Picklist entries

'Planned'=>'Planned',
'Held'=>'Held',
'Not Held'=>'Not Held',
'Completed'=>'Completed',
'Deferred'=>'Deferred',
'Not Started'=>'Not Started',
'In Progress'=>'In Progress',
'Pending Input'=>'Pending Input',
'LBL_REMAINDER_DAY'=>'days',
'LBL_REMAINDER_HRS'=>'hrs',
'Call'=>'Call',
'Meeting'=>'Meeting',

//added to send dates and time in calendar notification/invitation mail.

'Start date and time'=>'Start Date & Time',
'End date and time'=>'End Date & Time',
//this is for task
'End date'=>'End date',
'LBL_SET_DATE'=>'Set date..',
'Recurrence'=>'Recurrence',

//added to send invitation mail Subject.
'INVITATION'=>' Invitation ',

// Added/Updated for vtiger CRM 5.0.4
'LBL_YEAR_BUTTON_TITLE'=>'Year [Alt+Y]',
'LBL_SELECT_CONTACT'=>'Select Contacts',
'SHARED_EVENT_DEL_MSG'=>'The User does not have permission to Edit/Delete Shared Event.',
//added to fix ticket#4525
'LBL_CREATED'=>'created',
'LBL_UPDATED'=>'updated',

//Added after 5.0.4 GA
'LBL_BUSY' => 'Busy',

//Custom Fields support for Calendar
'LBL_CUSTOM_INFORMATION'=>'Custom Information',

// Repeat Event support for Calendar
'LBL_UNTIL' => 'Until',
'LBL_SET_DATE'=>'Set Date',

'LBL_MINE' =>'Mine',

);

?>
